<?php
/**
 * Dynamic CSS for the frontend.
 *
 * @package Startup
 */

defined( 'WPINC' ) || exit;

/**
 * Helper function.
 * Merge and combine the CSS elements.
 *
 * @param  string|array $elements An array of our elements.
 *                                If we use a string then it is directly returned.
 * @return string
 */
function startup_implode( $elements = array() ) {

	if ( ! is_array( $elements ) ) {
		return $elements;
	}

	// Make sure our values are unique.
	$elements = array_unique( $elements );

	// Sort elements alphabetically.
	// This way all duplicate items will be merged in the final CSS array.
	sort( $elements );

	// Implode items and return the value.
	return implode( ',', $elements );

}

/**
 * Maps elements from dynamic css to the selector.
 *
 * @param  array  $elements The elements.
 * @param  string $selector The selector.
 * @return array
 */
function startup_map_selector( $elements, $selector ) {
	$array = array();

	foreach ( $elements as $element ) {
		$array[] = $element . $selector;
	}

	return $array;
}

/**
 * Map CSS selectors from values.
 *
 * @param array $css    Array of dynamic CSS.
 * @param array $values Array of values.
 */
function startup_map_css_selectors( &$css, $values ) {
	if ( isset( $values['css-selectors'] ) ) {
		$elements = $values['css-selectors'];
		unset( $values['css-selectors'] );

		$css[ $elements ] = $values;
	}
}

/**
 * Merge CSS values.
 *
 * @param array $css    Array of dynamic CSS.
 * @param array $values Array of values.
 */
function startup_merge_value( &$css, $values ) {
	foreach ( (array) $values as $id => $val ) {
		$css[ $id ] = $val;
	}
}

/**
 * Format of the $css array:
 * $css['media-query']['element']['property'] = value
 *
 * If no media query is required then set it to 'global'
 *
 * If we want to add multiple values for the same property then we have to make it an array like this:
 * $css[media-query][element]['property'][] = value1
 * $css[media-query][element]['property'][] = value2
 *
 * Multiple values defined as an array above will be parsed separately.
 */
function startup_dynamic_css_array() {

	global $wp_version;

	$css       = array();
	$c_page_id = startup()->get_page_id();

	// Site Background.
	$css['global']['html body'] = Startup_Sanitize::background( startup_get_settings( 'mts_background' ) );
	// Top Bar Background
	$css['global']['#site-header .top-bar, .mobile-menu-active .navigation.mobile-menu-wrapper'] = Startup_Sanitize::background( startup_get_settings( 'top_bar_background' ) );
	// Nav Background.
	$css['global']['#header, #site-header.header-layout2 #header, #header.sticky-navigation.sticky-navigation-active'] = Startup_Sanitize::background( startup_get_settings( 'header_background' ) );
	// Content Font.
	startup_map_css_selectors( $css['global'], Startup_Sanitize::typography( startup_get_settings( 'content_font' ) ) );
	// Logo Font.
	startup_map_css_selectors( $css['global'], Startup_Sanitize::typography( startup_get_settings( 'startup_logo' ) ) );
	// Top bar font.
	startup_map_css_selectors( $css['global'], Startup_Sanitize::typography( startup_get_settings( 'top_bar_font' ) ) );
	// Primary Navigation font.
	startup_map_css_selectors( $css['global'], Startup_Sanitize::typography( startup_get_settings( 'secondary_navigation_font' ) ) );
	// Homepage post title font.
	startup_map_css_selectors( $css['global'], Startup_Sanitize::typography( startup_get_settings( 'home_title_font' ) ) );
	// Pagination.
	startup_map_css_selectors( $css['global'], Startup_Sanitize::typography( startup_get_settings( 'pagination_font' ) ) );
	// single heading font.
	startup_map_css_selectors( $css['global'], Startup_Sanitize::typography( startup_get_settings( 'pages_title_heading_font' ) ) );
	startup_map_css_selectors( $css['global'], Startup_Sanitize::typography( startup_get_settings( 'page_title_heading_font' ) ) );
	// single subheading font.
	startup_map_css_selectors( $css['global'], Startup_Sanitize::typography( startup_get_settings( 'pages_title_subheading_font' ) ) );
	// Breadcrumbs font.
	startup_map_css_selectors( $css['global'], Startup_Sanitize::typography( startup_get_settings( 'breadcrumb_font' ) ) );
	// Single post title font.
	startup_map_css_selectors( $css['global'], Startup_Sanitize::typography( startup_get_settings( 'single_title_font' ) ) );
	// Single Page titles font.
	startup_map_css_selectors( $css['global'], Startup_Sanitize::typography( startup_get_settings( 'single_page_titles_font' ) ) );
	// Related Posts Section title font.
	startup_map_css_selectors( $css['global'], Startup_Sanitize::typography( startup_get_settings( 'related_post_title_font' ) ) );
	// Single subscribe box.
	startup_map_css_selectors( $css['global'], Startup_Sanitize::typography( startup_get_settings( 'single_subscribe_title_font' ) ) );
	startup_map_css_selectors( $css['global'], Startup_Sanitize::typography( startup_get_settings( 'single_subscribe_text_font' ) ) );
	startup_map_css_selectors( $css['global'], Startup_Sanitize::typography( startup_get_settings( 'single_subscribe_input_font' ) ) );
	startup_map_css_selectors( $css['global'], Startup_Sanitize::typography( startup_get_settings( 'single_subscribe_submit_font' ) ) );
	startup_map_css_selectors( $css['global'], Startup_Sanitize::typography( startup_get_settings( 'single_subscribe_small_text_font' ) ) );
	// Author Box.
	startup_map_css_selectors( $css['global'], Startup_Sanitize::typography( startup_get_settings( 'single_authorbox_title_font' ) ) );
	startup_map_css_selectors( $css['global'], Startup_Sanitize::typography( startup_get_settings( 'single_authorbox_author_name_font' ) ) );
	startup_map_css_selectors( $css['global'], Startup_Sanitize::typography( startup_get_settings( 'single_authorbox_text_font' ) ) );
	// Footer Nav.
	startup_map_css_selectors( $css['global'], Startup_Sanitize::typography( startup_get_settings( 'footer_nav_font' ) ) );
	// Sidebar widget title font.
	startup_map_css_selectors( $css['global'], Startup_Sanitize::typography( startup_get_settings( 'sidebar_title_font' ) ) );
	// Sidebar widget font.
	startup_map_css_selectors( $css['global'], Startup_Sanitize::typography( startup_get_settings( 'sidebar_url' ) ) );
	startup_map_css_selectors( $css['global'], Startup_Sanitize::typography( startup_get_settings( 'sidebar_font' ) ) );
	startup_map_css_selectors( $css['global'], Startup_Sanitize::typography( startup_get_settings( 'sidebar_post_title' ) ) );
	startup_map_css_selectors( $css['global'], Startup_Sanitize::typography( startup_get_settings( 'sidebar_postinfo_font' ) ) );
	// Footer widget title font.
	startup_map_css_selectors( $css['global'], Startup_Sanitize::typography( startup_get_settings( 'footer_startup_logo' ) ) );
	startup_map_css_selectors( $css['global'], Startup_Sanitize::typography( startup_get_settings( 'top_footer_title_font' ) ) );
	// Footer link font.
	startup_map_css_selectors( $css['global'], Startup_Sanitize::typography( startup_get_settings( 'top_footer_link_font' ) ) );
	startup_map_css_selectors( $css['global'], Startup_Sanitize::typography( startup_get_settings( 'top_footer_post_title' ) ) );
	// Footer widget font.
	startup_map_css_selectors( $css['global'], Startup_Sanitize::typography( startup_get_settings( 'top_footer_font' ) ) );
	startup_map_css_selectors( $css['global'], Startup_Sanitize::typography( startup_get_settings( 'top_footer_meta_font' ) ) );
	// Copyrights section font.
	startup_map_css_selectors( $css['global'], Startup_Sanitize::typography( startup_get_settings( 'copyrights_font' ) ) );
	// H1 title in the content.
	startup_map_css_selectors( $css['global'], Startup_Sanitize::typography( startup_get_settings( 'h1_headline' ) ) );
	// H2 title in the content.
	startup_map_css_selectors( $css['global'], Startup_Sanitize::typography( startup_get_settings( 'h2_headline' ) ) );
	// H3 title in the content.
	startup_map_css_selectors( $css['global'], Startup_Sanitize::typography( startup_get_settings( 'h3_headline' ) ) );
	// H4 title in the content.
	startup_map_css_selectors( $css['global'], Startup_Sanitize::typography( startup_get_settings( 'h4_headline' ) ) );
	// H5 title in the content.
	startup_map_css_selectors( $css['global'], Startup_Sanitize::typography( startup_get_settings( 'h5_headline' ) ) );
	// H6 title in the content.
	startup_map_css_selectors( $css['global'], Startup_Sanitize::typography( startup_get_settings( 'h6_headline' ) ) );

	// Footer background.
	$css['global']['#site-footer'] = Startup_Sanitize::background( startup_get_settings( 'mts_footer_background' ) );

	//Archive settings
	startup_map_css_selectors( $css['global'], Startup_Sanitize::typography( startup_get_settings( 'archive_meta_info_font' ) ) );
	startup_map_css_selectors( $css['global'], Startup_Sanitize::typography( startup_get_settings( 'archive_post_title_font' ) ) );
	startup_map_css_selectors( $css['global'], Startup_Sanitize::typography( startup_get_settings( 'archive_post_excerpt_font' ) ) );

	//Featured Area
	startup_map_css_selectors( $css['global'], Startup_Sanitize::typography( startup_get_settings( 'featured_area_title_font' ) ) );
	startup_map_css_selectors( $css['global'], Startup_Sanitize::typography( startup_get_settings( 'featured_area_subtitle_font' ) ) );
	$css['global']['.featured-area-section'] = Startup_Sanitize::background( startup_get_settings( 'featured_area_background' ) );
	startup_merge_value( $css['global']['.featured-area-section'], Startup_Sanitize::margin( startup_get_settings( 'featured_area_margin' ) ) );
	startup_merge_value( $css['global']['.featured-area-section'], Startup_Sanitize::padding( startup_get_settings( 'featured_area_padding' ) ) );
	//$css['global']['.featured-area-button .button']['background-color'] = Startup_Sanitize::color( startup_get_settings( 'featured_area_button_bg' ) );
	$css['global']['.featured-area-button .button'] = Startup_Sanitize::background( startup_get_settings( 'featured_area_button_bg' ) );
	//Featured Area Image Position
	$featured_area_image_position = startup_get_settings( 'featured_area_image_position' );
	foreach ( $featured_area_image_position as $key => $position ) {
		$css['global']['.featured-right'][ $key ] = $position;
	}

	startup_dynamic_css_skin( $css );
	startup_sidebar_position( $css );
	startup_header( $css );
	startup_sidebar_styling( $css );
	startup_home_layouts( $css );
	startup_post_layouts( $css );
	startup_post_pagination( $css );
	startup_footer( $css );
	startup_single( $css );
	startup_single_social_buttons( $css );
	startup_misc_css( $css );

	return apply_filters( 'startup_dynamic_css_array', $css );
}

/**
 * Skin CSS
 *
 * @param array $css Array of dynamic CSS.
 */
function startup_dynamic_css_skin( &$css ) {

	// Primary Color.
	$primary_color_scheme = Startup_Sanitize::color( startup_get_settings( 'primary_color_scheme' ) );

	// Text Color.
	$elements = array(
		'a',
		'body a:hover',
		'.breadcrumb a',
		'.rank-math-breadcrumb a',
		'.single_post .thecontent a',
		'.reply a',
		'.reply i',
		'.featured-content a.title:hover',
		'.latestPost .title a:hover',
		'.related-posts .title a:hover',
		'.layout-default .latestPost .title a:hover',
		'.woocommerce ul.products li.product .price',
		'.product_list_widget .amount',
		'.woocommerce div.product p.price, .woocommerce div.product span.price',
		'.shareit-circular.standard .fa:hover',
		'.textwidget a',
		'#wp-calendar td#today',
		'.pnavigation2 a',
		'footer .widget li a:hover',
		'#sidebar .widget li a:hover',
		'.title a:hover',
		'#tabber .inside li a:hover',
		'.fn a',
		'.related-posts .title a:hover',
		'.layout-subscribe .widget #wp-subscribe .title span',
		'.footer-nav li a:hover',
		'blockquote:after',
		'article ul li::before',
		'blockquote::before',
		'.button.border:hover',
		' #copyright-note a',
		'.post-info a i',
		'.service-item a:hover h3',
		'.twogrid-section h3 a:hover',
		'#site-footer .post-title a:hover',
		'#site-footer .entry-title a:hover',
		'.sidebar .widget a:hover',
		'.sidebar .post-title a:hover',
		'.sidebar .entry-title a:hover',
		'.post-info > span i',
		'.widget li span.total-posts-number',
		'.readMore a.button',
		'.layout-default .readMore a.button',
	);

	$css['global'][ startup_implode( $elements ) ]['color'] = $primary_color_scheme;
	$css['global']['#sidebar .widget a:hover']['color']     = $primary_color_scheme;
	//Read More buttons
	$css['global']['body a.button svg path']['fill'] = $primary_color_scheme;

	// Text Color Important.
	$elements = array(
		'.layout-grid .latestPost .title a:hover',
		'.widget .review_thumb_large .review-result',
		'.widget .review_thumb_large .review-total-only.large-thumb',
		'.aboutme-social a',
		'.widget .readMore a',
		'.widget .post-info a',
		'.post-info a:hover',
	);
	$css['global'][ startup_implode( $elements ) ]['color'] = $primary_color_scheme . '!important';

	// Background Color.
	$elements = array(
		'.pace .pace-progress',
		'#mobile-menu-wrapper ul li a:hover',
		'.navigation #wpmm-megamenu .wpmm-pagination a',
		'.wpmm-megamenu-showing.wpmm-light-scheme',
		'.mts-subscribe input[type="submit"]',
		'.widget_product_search button[type="submit"]',
		'#move-to-top:hover',
		'#tabber ul.tabs li a.selected',
		'.navigation ul .sfHover a',
		'.widget-slider .slide-caption',
		'.owl-prev:hover, .owl-next:hover',
		'.widget .wp-subscribe-wrap h4.title span.decor:after',
		'.woocommerce a.button',
		'.woocommerce-page a.button',
		'.woocommerce button.button',
		'.woocommerce-page button.button',
		'.woocommerce input.button',
		'.woocommerce-page input.button',
		'.woocommerce #respond input#submit',
		'.woocommerce-page #respond input#submit',
		'.woocommerce #content input.button',
		'.woocommerce-page #content input.button',
		'.woocommerce .bypostauthor:after',
		'.woocommerce nav.woocommerce-pagination ul li span.current',
		'.woocommerce-page nav.woocommerce-pagination ul li span.current',
		'.woocommerce #content nav.woocommerce-pagination ul li span.current',
		'.woocommerce-page #content nav.woocommerce-pagination ul li span.current',
		'.woocommerce nav.woocommerce-pagination ul li a:hover',
		'.woocommerce-page nav.woocommerce-pagination ul li a:hover',
		'.woocommerce #content nav.woocommerce-pagination ul li a:hover',
		'.woocommerce-page #content nav.woocommerce-pagination ul li a:hover',
		'.woocommerce nav.woocommerce-pagination ul li a:focus',
		'.woocommerce-page nav.woocommerce-pagination ul li a:focus',
		'.woocommerce #content nav.woocommerce-pagination ul li a:focus',
		'.woocommerce-page #content nav.woocommerce-pagination ul li a:focus',
		'.woocommerce a.button',
		'.woocommerce-page a.button',
		'.woocommerce button.button',
		'.woocommerce-page button.button',
		'.woocommerce input.button',
		'.woocommerce-page input.button',
		'.woocommerce #respond input#submit',
		'.woocommerce-page #respond input#submit',
		'.woocommerce #content input.button',
		'.woocommerce-page #content input.button',
		'.woocommerce #respond input#submit.alt.disabled',
		'.woocommerce #respond input#submit.alt.disabled:hover',
		'.woocommerce #respond input#submit.alt:disabled',
		'.woocommerce #respond input#submit.alt:disabled:hover',
		'.woocommerce #respond input#submit.alt:disabled[disabled]',
		'.woocommerce #respond input#submit.alt:disabled[disabled]:hover',
		'.woocommerce a.button.alt.disabled, .woocommerce a.button.alt.disabled:hover',
		'.woocommerce a.button.alt:disabled',
		'.woocommerce a.button.alt:disabled:hover',
		'.woocommerce a.button.alt:disabled[disabled]',
		'.woocommerce a.button.alt:disabled[disabled]:hover',
		'.woocommerce button.button.alt.disabled',
		'.woocommerce button.button.alt.disabled:hover',
		'.woocommerce button.button.alt:disabled',
		'.woocommerce button.button.alt:disabled:hover',
		'.woocommerce button.button.alt:disabled[disabled]',
		'.woocommerce button.button.alt:disabled[disabled]:hover',
		'.woocommerce input.button.alt.disabled',
		'.woocommerce input.button.alt.disabled:hover',
		'.woocommerce input.button.alt:disabled',
		'.woocommerce input.button.alt:disabled:hover',
		'.woocommerce input.button.alt:disabled[disabled]',
		'.woocommerce input.button.alt:disabled[disabled]:hover',
		'#wpmm-megamenu .review-total-only',
		'#searchsubmit',
		'#add_payment_method .wc-proceed-to-checkout a.checkout-button',
		'.woocommerce-cart .wc-proceed-to-checkout a.checkout-button',
		'.woocommerce-checkout .wc-proceed-to-checkout a.checkout-button',
		'.woocommerce #respond input#submit.alt',
		'.woocommerce a.button.alt',
		'.woocommerce button.button.alt',
		'.woocommerce input.button.alt',
		'.woocommerce-account .woocommerce-MyAccount-navigation li.is-active',
		'.widget #wp-subscribe form::after',
		'.button',
		'.instagram-button a',
		'.woocommerce .woocommerce-widget-layered-nav-dropdown__submit',
		'.layout-subscribe form:after',
		'.f-widget .widget #wp-subscribe form:after',
		'.owl-prev:hover, .owl-next:hover',
		'.woocommerce .widget_price_filter .ui-slider .ui-slider-handle',
		'.woocommerce .widget_price_filter .ui-slider .ui-slider-range',
		'.latestPost-review-wrapper',
		'.latestPost .review-type-circle.latestPost-review-wrapper',
		'.woocommerce span.onsale',
		'.widget .widget_wp_review_tab .review-total-only.large-thumb',
		'#sidebar .widget h3::before',
		'#sidebar .widget #wp-subscribe .title::before',
		'.f-widget .widget #wp-subscribe input.submit',
		'.owl-controls .owl-dot.active span',
		'.shareit-circular .social-icon',
		'.pages-title-section',
		'.author-social a',
		'footer .widget .review-total-only.small-thumb',
		'footer .widget .review-total-only',
		'.header-layout2 #header',
	);

	$css['global'][ startup_implode( $elements ) ]['background-color'] = $primary_color_scheme;

	// Buttons Background
	$elements = array(
		'.widget .sbutton',
		'.error404 .sbutton, .search .sbutton',
		'.search .sbutton',
		'#commentform input#submit',
		'#mtscontact_submit',
		'.widget #wp-subscribe input.submit',
	);

	startup_merge_value( $css['global'][ startup_implode( $elements ) ], Startup_Sanitize::background( startup_get_settings( 'mts_buttons_bg' ) ) );

	// Background Color Important.
	$elements = array(
		'.tags a:hover',
		'.tagcloud a:hover',
		'#sidebar .widget .tagcloud a:hover',
		'.widget .wpt_widget_content #tags-tab-content ul li a:hover ',
		'footer .widget .wpt_widget_content .tab_title.selected a',
		'footer .widget .wp_review_tab_widget_content .tab_title.selected a',
	);
	$css['global'][ startup_implode( $elements ) ]['background-color'] = $primary_color_scheme . '!important';

	// Border Color.
	$elements = array(
		'.flex-control-thumbs .flex-active',
		'#wrapper .cooked-recipe-ingredients .cooked-ingredient-checkbox',
		'blockquote',
		'.commentmetadata',
	);

	$css['global'][ startup_implode( $elements ) ]['border-color'] = $primary_color_scheme;

	// Border Color.
	$elements = array(
		'#sidebar .widget .wpt_widget_content .tab_title.selected a',
		'#sidebar .widget .wp_review_tab_widget_content .tab_title.selected a',
		'.tagcloud a:hover',
		'.tags a:hover',
		'.widget .wpt_widget_content #tags-tab-content ul li a:hover',
	);

	$css['global'][ startup_implode( $elements ) ]['border-color'] = $primary_color_scheme . '!important';

	//Paged header background color
	$paged_header = Startup_Sanitize::background( startup_get_settings( 'header_background' ) );
	if ( empty( $paged_header['background'] ) ) {
		$css['global']['.paged #header']['background']                   = $primary_color_scheme;
		$css['global']['#header.sticky-navigation-active']['background'] = $primary_color_scheme;
	}
	if ( empty( $paged_header['background'] ) && empty( startup_get_settings( 'show_pages_title' ) ) ) {
		$css['global']['#header']['background'] = $primary_color_scheme;
		$css['global']['#wrapper']['clear']     = 'both';
	}

}

/**
 * Sidebar Position
 *
 * @param array $css Array of dynamic CSS.
 */
function startup_sidebar_position( &$css ) {

	// Sidebar position.
	$sidebar_position = startup_get_settings( 'mts_layout' );

	$sidebar_metabox_location = '';
	if ( is_page() || is_single() ) {
		$sidebar_metabox_location = get_post_meta( get_the_ID(), '_mts_sidebar_location', true );
	}

	if ( 'right' !== $sidebar_metabox_location && ( 'sclayout' === $sidebar_position || 'left' === $sidebar_metabox_location ) ) {

		$css['global']['.article']['float']        = 'right';
		$css['global']['.sidebar.c-4-12']['float'] = 'left';
		if ( null !== startup_get_settings( 'mts_social_button_position' ) && 'floating' === startup_get_settings( 'mts_social_button_position' ) ) {
			$elements = array(
				'.shareit.shareit-default.floating',
				'.shareit.shareit-circular.floating',
				'.shareit.shareit-rectwithname.floating',
			);
			$css['global'][ startup_implode( $elements ) ]['margin'] = '0 772px 0';
		}
	}

}

/**
 * Header
 *
 * @param array $css Array of dynamic CSS.
 */
function startup_header( &$css ) {

	// Header.
	$header_class = array(
		'#header',
	);
	startup_merge_value( $css['global'][ startup_implode( $header_class ) ], Startup_Sanitize::margin( startup_get_settings( 'header_margin' ) ) );
	startup_merge_value( $css['global'][ startup_implode( $header_class ) ], Startup_Sanitize::padding( startup_get_settings( 'header_padding' ) ) );

	startup_merge_value( $css['global']['.top-bar'], Startup_Sanitize::margin( startup_get_settings( 'top_bar_margin' ) ) );
	startup_merge_value( $css['global']['.top-bar'], Startup_Sanitize::padding( startup_get_settings( 'top_bar_padding' ) ) );
	// Header Border.
	$header_border = Startup_Sanitize::border( startup_get_settings( 'mts_header_border' ) );
	$css['global'][ startup_implode( $header_class ) ][ $header_border['direction'] ] = $header_border ['value'];

	// Main Nav.
	$main_nav_classes  = array(
		'#secondary-navigation .navigation ul ul a',
		'#secondary-navigation .navigation ul ul a:link',
		'#secondary-navigation .navigation ul ul a:visited',
	);
	$nav_hover_classes = array(
		'#secondary-navigation li:hover',
		'#secondary-navigation .navigation ul ul a:hover',
		'#secondary-navigation li:hover > a',
		'.contact-item a:hover',
	);
	// Button Background & color.
	$css['global']['#site-header .nav-button .button']          = Startup_Sanitize::background( startup_get_settings( 'nav_button_bg' ) );
	$css['global']['#site-header .nav-button .button']['color'] = Startup_Sanitize::color( startup_get_settings( 'nav_button_color' ) );

	$css['global'][ startup_implode( $nav_hover_classes ) ]['color'] = Startup_Sanitize::color( startup_get_settings( 'main_navigation_hover_color' ) );
	$css['global'][ startup_implode( $main_nav_classes ) ]           = Startup_Sanitize::background( startup_get_settings( 'main_navigation_dropdown_bg' ) );
	$css['global'][ startup_implode( $main_nav_classes ) ]['color']  = Startup_Sanitize::color( startup_get_settings( 'main_navigation_dropdown_color' ) );

	//Pages Title Background
	$css['global']['.pages-title-section'] = Startup_Sanitize::background( startup_get_settings( 'pages_title_bg' ) );

	$pages_title_bg = startup_get_settings( 'pages_title_bg' );
	if ( ( ! empty( $pages_title_bg ) && ! empty( $pages_title_bg['image_upload'] ) ) || ! startup_get_settings( 'pages_title_circle' ) ) {
		$css['global']['.pages-title-section::after']['display'] = 'none';
	}

	// Contact info.
	$contacts = startup_get_settings( 'top_bar_contact' );
	$i        = 0;
	if ( ! empty( $contacts ) && is_array( $contacts ) ) {
		foreach ( $contacts as $contact ) :
			++$i;
			if ( isset( $contact['contact_color'] ) ) {
				$css['global'][ '.contact-item.item-' . $i ]['color'] = Startup_Sanitize::color( $contact['contact_color'] );
			}
		endforeach;
	}

	// Header Ad.
	startup_merge_value( $css['global']['.widget-header, .small-header .widget-header'], Startup_Sanitize::margin( startup_get_settings( 'mts_header_adcode_margin' ) ) );

	// Ad-Blocker.
	$css['global']['.navigation-banner']['background'] = Startup_Sanitize::color( startup_get_settings( 'navigation_ad_background' ) );
}

/**
 * Social Share Styling
 *
 * @param array $css Array of dynamic CSS.
 */
function startup_single_social_buttons( &$css ) {

	$social_shadow = startup_get_settings( 'social_styling_box_shadow' );

	// Social share.
	$css['global']['.shareit.floating'] = Startup_Sanitize::background( startup_get_settings( 'social_styling_background' ) );
	//startup_merge_value( $css['global']['.shareit.floating'], Startup_Sanitize::margin( startup_get_settings( 'social_styling_margin' ) ) );
	$elements = array(
		'.shareit',
		'.shareit.floating',
		'.ss-full-width .shareit.shareit-default.floating',
		'.ss-full-width .shareit.shareit-circular.floating',
		'.ss-full-width .shareit.shareit-rectwithname.floating',
	);
	startup_merge_value( $css['global'][ startup_implode( $elements ) ], Startup_Sanitize::margin( startup_get_settings( 'social_styling_margin' ) ) );
	startup_merge_value( $css['global'][ startup_implode( $elements ) ], Startup_Sanitize::padding( startup_get_settings( 'social_styling_padding' ) ) );

	// Social share border.
	$social_border = Startup_Sanitize::border( startup_get_settings( 'social_styling_border' ) );
	$css['global'][ startup_implode( $elements ) ][ $social_border ['direction'] ] = $social_border ['value'];

	$social_button_layout   = startup_get_settings( 'social_button_layout' );
	$social_button_position = startup_get_settings( 'mts_social_button_position' );
	if ( ! empty( $social_button_position ) && is_array( $social_button_position ) ) {
		foreach ( $social_button_position as $key => $position ) {
			$css['global'][ '.shareit.shareit-' . $social_button_layout . '.floating' ][ $key ] = $position;
		}
	}
}

/**
 * Sidebar styling
 *
 * @param array $css Array of dynamic CSS.
 */
function startup_sidebar_styling( &$css ) {

	// Sidebar.
	startup_merge_value( $css['global']['#sidebar .widget'], Startup_Sanitize::background( startup_get_settings( 'mts_sidebar_styling_background' ) ) );
	startup_merge_value( $css['global']['#sidebar .widget'], Startup_Sanitize::margin( startup_get_settings( 'mts_sidebar_styling_margin' ) ) );
	startup_merge_value( $css['global']['#sidebar .widget'], Startup_Sanitize::padding( startup_get_settings( 'mts_sidebar_styling_padding' ) ) );
	// Sidebar border.
	$sidebar_border = Startup_Sanitize::border( startup_get_settings( 'sidebar_styling_border' ) );
	$css['global']['#sidebar .widget'][ $sidebar_border['direction'] ] = $sidebar_border['value'];

	// Sidebar title.
	$sidebar_title                   = '#sidebar .widget h3, #sidebar .widget #wp-subscribe .title';
	$css['global'][ $sidebar_title ] = Startup_Sanitize::background( startup_get_settings( 'mts_sidebar_title_styling_background' ) );
	startup_merge_value( $css['global'][ $sidebar_title ], Startup_Sanitize::padding( startup_get_settings( 'mts_sidebar_title_styling_padding' ) ) );
	startup_merge_value( $css['global'][ $sidebar_title ], Startup_Sanitize::margin( startup_get_settings( 'mts_sidebar_title_styling_margin' ) ) );
	// Sidebar Title border.
	$sidebar_title_border = Startup_Sanitize::border( startup_get_settings( 'widget_title_border' ) );
	$css['global'][ $sidebar_title ][ $sidebar_title_border['direction'] ] = $sidebar_title_border['value'];
}

/**
 * Layout CSS
 *
 * @param array $css Array of dynamic CSS.
 */
function startup_home_layouts( &$css ) {

	//Homepage Section.
	$features = startup_get_settings( 'homepage_layout' );

	foreach ( (array) $features as $feature ) :

		if ( ! isset( $feature['home_unique_id'] ) ) {
			continue;
		}

		$posts_layout = isset( $feature['home_layout'] ) ? $feature['home_layout'] : '';
		$unique_id    = $feature['home_unique_id'];
		$post_class   = 'section.layout-' . $unique_id;

		startup_merge_value( $css['global'][ $post_class ], Startup_Sanitize::margin( startup_get_settings( 'home_section_margin_' . $unique_id ) ) );
		startup_merge_value( $css['global'][ $post_class ], Startup_Sanitize::padding( startup_get_settings( 'home_section_padding_' . $unique_id ) ) );
		startup_merge_value( $css['global'][ $post_class ], Startup_Sanitize::background( startup_get_settings( 'home_section_background_' . $unique_id ) ) );

		/**
		 * Three Column Section.
		 */
		startup_merge_value( $css['global'][ $post_class . '.threefeatures-section .container' ], Startup_Sanitize::margin( startup_get_settings( 'threefeatures_margin_' . $unique_id ) ) );

		startup_map_css_selectors( $css['global'], Startup_Sanitize::typography( startup_get_settings( 'threefeatures_title_font_' . $unique_id ) ) );
		startup_map_css_selectors( $css['global'], Startup_Sanitize::typography( startup_get_settings( 'threefeatures_text_font_' . $unique_id ) ) );
		$css['global'][ $post_class . '.threefeatures-section .container' ]['border-radius'] = Startup_Sanitize::size( startup_get_settings( 'threefeatures_border_radius_' . $unique_id ) . 'px' );
		if ( 0 === startup_get_settings( 'threefeatures_box_shadow_' . $unique_id ) ) {
			$css['global'][ $post_class . '.threefeatures-section' ]['box-shadow'] = 'none';
		}

		$threefeatures = startup_get_settings( 'home_threefeatures_' . $unique_id );
		$i             = 0;
		if ( ! empty( $threefeatures ) && is_array( $threefeatures ) ) {
			foreach ( $threefeatures as $feature ) {
				++$i;
				$css['global'][ $post_class . ' .feature-item.item-' . $i ]['color']              = Startup_Sanitize::color( $feature[ 'threefeatures_icon_color_' . $unique_id ] );
				$css['global'][ $post_class . ' .feature-item.item-' . $i . ' svg path' ]['fill'] = Startup_Sanitize::color( $feature[ 'threefeatures_icon_color_' . $unique_id ] );
			}
		}

		/**
		 * Two Column Section.
		 */
		startup_map_css_selectors( $css['global'], Startup_Sanitize::typography( startup_get_settings( 'twofeatures_heading_font_' . $unique_id ) ) );
		startup_map_css_selectors( $css['global'], Startup_Sanitize::typography( startup_get_settings( 'twofeatures_subheading_font_' . $unique_id ) ) );
		startup_map_css_selectors( $css['global'], Startup_Sanitize::typography( startup_get_settings( 'twofeatures_title_font_' . $unique_id ) ) );
		startup_map_css_selectors( $css['global'], Startup_Sanitize::typography( startup_get_settings( 'twofeatures_text_font_' . $unique_id ) ) );
		startup_merge_value( $css['global'][ $post_class . ' .twofeatures-button .button' ], Startup_Sanitize::background( startup_get_settings( 'twofeatures_button_bg_' . $unique_id ) ) );
		$css['global'][ $post_class . ' .twofeatures-button .button' ]['color'] = Startup_Sanitize::color( startup_get_settings( 'twofeatures_button_color_' . $unique_id ) );
		$css['global'][ $post_class . ' .twofeatures-button svg path' ]['fill'] = Startup_Sanitize::color( startup_get_settings( 'twofeatures_button_color_' . $unique_id ) );
		startup_merge_value( $css['global'][ $post_class . ' .twofeatures-button .button' ], Startup_Sanitize::padding( startup_get_settings( 'twofeatures_button_padding_' . $unique_id ) ) );
		startup_merge_value( $css['global'][ $post_class . ' .twofeatures-button' ], Startup_Sanitize::margin( startup_get_settings( 'twofeatures_button_margin_' . $unique_id ) ) );

		$twofeatures = startup_get_settings( 'home_twofeatures_' . $unique_id );
		$i           = 0;
		if ( ! empty( $twofeatures ) && is_array( $twofeatures ) ) {
			foreach ( $twofeatures as $feature ) {
				++$i;
				$css['global'][ $post_class . ' .twofeature-item.item-' . $i . ' .feature-icon' ]['color']            = Startup_Sanitize::color( $feature[ 'twofeatures_icon_color_' . $unique_id ] );
				$css['global'][ $post_class . ' .twofeature-item.item-' . $i . ' h3' ]['color']                       = Startup_Sanitize::color( $feature[ 'twofeatures_icon_bg_' . $unique_id ] );
				$css['global'][ $post_class . ' .twofeature-item.item-' . $i . ' .feature-icon' ]['background-color'] = Startup_Sanitize::color( $feature[ 'twofeatures_icon_bg_' . $unique_id ] );
			}
		}

		if ( 'left' === startup_get_settings( 'twofeatures_content_position_' . $unique_id ) ) {
			$css['global'][ $post_class . ' .twofeatures-items' ]['float']         = 'left';
			$css['global'][ $post_class . ' .twofeatures-items' ]['padding-left']  = '0px';
			$css['global'][ $post_class . ' .twofeatures-items' ]['padding-right'] = '4%';

			//Image Position
			$twofeatures_image_position = startup_get_settings( 'twofeatures_image_position_' . $unique_id );
			foreach ( $twofeatures_image_position as $key => $position ) {
				$css['global'][ $post_class . ' .twofeatures-image' ][ $key ] = $position;
			}
		}

		/**
		 * 4 Column Section.
		 */
		startup_map_css_selectors( $css['global'], Startup_Sanitize::typography( startup_get_settings( 'fourfeatures_heading_font_' . $unique_id ) ) );
		startup_map_css_selectors( $css['global'], Startup_Sanitize::typography( startup_get_settings( 'fourfeatures_subheading_font_' . $unique_id ) ) );
		startup_map_css_selectors( $css['global'], Startup_Sanitize::typography( startup_get_settings( 'fourfeatures_title_font_' . $unique_id ) ) );
		startup_map_css_selectors( $css['global'], Startup_Sanitize::typography( startup_get_settings( 'fourfeatures_text_font_' . $unique_id ) ) );
		startup_merge_value( $css['global'][ $post_class . ' .fourfeatures-button .button' ], Startup_Sanitize::background( startup_get_settings( 'fourfeatures_button_bg_' . $unique_id ) ) );
		$css['global'][ $post_class . ' .fourfeatures-button .button' ]['color'] = Startup_Sanitize::color( startup_get_settings( 'fourfeatures_button_color_' . $unique_id ) );
		$css['global'][ $post_class . ' .fourfeatures-button svg path' ]['fill'] = Startup_Sanitize::color( startup_get_settings( 'fourfeatures_button_color_' . $unique_id ) );
		startup_merge_value( $css['global'][ $post_class . ' .fourfeatures-button .button' ], Startup_Sanitize::padding( startup_get_settings( 'fourfeatures_button_padding_' . $unique_id ) ) );
		startup_merge_value( $css['global'][ $post_class . ' .fourfeatures-button' ], Startup_Sanitize::margin( startup_get_settings( 'fourfeatures_button_margin_' . $unique_id ) ) );

		$fourfeatures = startup_get_settings( 'home_fourfeatures_' . $unique_id );
		$i            = 0;
		if ( ! empty( $fourfeatures ) && is_array( $fourfeatures ) ) {
			foreach ( $fourfeatures as $feature ) {
				++$i;
				$css['global'][ $post_class . ' .fourfeature-item.item-' . $i . ' .feature-icon' ]['color']            = Startup_Sanitize::color( $feature[ 'fourfeatures_icon_color_' . $unique_id ] );
				$css['global'][ $post_class . ' .fourfeature-item.item-' . $i . ' .feature-icon' ]['background-color'] = Startup_Sanitize::color( $feature[ 'fourfeatures_icon_bg_' . $unique_id ] );
			}
		}

		/**
		 * CTA Section.
		 */
		startup_map_css_selectors( $css['global'], Startup_Sanitize::typography( startup_get_settings( 'cta_title_font_' . $unique_id ) ) );
		startup_map_css_selectors( $css['global'], Startup_Sanitize::typography( startup_get_settings( 'cta_text_font_' . $unique_id ) ) );
		startup_merge_value( $css['global'][ $post_class . ' .cta-button .button' ], Startup_Sanitize::background( startup_get_settings( 'cta_button_bg_' . $unique_id ) ) );
		$css['global'][ $post_class . ' .cta-button .button' ]['color'] = Startup_Sanitize::color( startup_get_settings( 'cta_button_color_' . $unique_id ) );
		startup_merge_value( $css['global'][ $post_class . ' .cta-button .button' ], Startup_Sanitize::padding( startup_get_settings( 'cta_button_padding_' . $unique_id ) ) );

		/**
		 * Pricing Table
		 */
		startup_map_css_selectors( $css['global'], Startup_Sanitize::typography( startup_get_settings( 'pricing_heading_font_' . $unique_id ) ) );
		startup_map_css_selectors( $css['global'], Startup_Sanitize::typography( startup_get_settings( 'pricing_subheading_font_' . $unique_id ) ) );
		startup_map_css_selectors( $css['global'], Startup_Sanitize::typography( startup_get_settings( 'pricing_title_font_' . $unique_id ) ) );
		startup_map_css_selectors( $css['global'], Startup_Sanitize::typography( startup_get_settings( 'pricing_text_font_' . $unique_id ) ) );
		startup_map_css_selectors( $css['global'], Startup_Sanitize::typography( startup_get_settings( 'pricing_amount_font_' . $unique_id ) ) );
		startup_merge_value( $css['global'][ $post_class . ' .pricing-button .button' ], Startup_Sanitize::background( startup_get_settings( 'pricing_button_bg_' . $unique_id ) ) );
		$css['global'][ $post_class . ' .pricing-button .button' ]['color'] = Startup_Sanitize::color( startup_get_settings( 'pricing_button_color_' . $unique_id ) );

		$pricing = startup_get_settings( 'home_pricing_' . $unique_id );
		$i       = 0;
		if ( ! empty( $pricing ) && is_array( $pricing ) ) {
			foreach ( $pricing as $price ) {
				++$i;
				$css['global'][ $post_class . ' .pricing-item.item-' . $i . ' .pricing-icon' ]['color']               = Startup_Sanitize::color( $price[ 'pricing_icon_color_' . $unique_id ] );
				$css['global'][ $post_class . ' .pricing-item.item-' . $i . ' .pricing-icon' ]['background-color']    = Startup_Sanitize::color( $price[ 'pricing_icon_bg_' . $unique_id ] );
				$css['global'][ $post_class . ' .pricing-item.item-' . $i ]['background-color']                       = Startup_Sanitize::color( $price[ 'pricing_table_bg_' . $unique_id ] );
				$css['global'][ $post_class . ' .pricing-item.item-' . $i . ' h3' ]['color']                          = Startup_Sanitize::color( $price[ 'pricing_table_title_color_' . $unique_id ] );
				$css['global'][ $post_class . ' .pricing-item.item-' . $i . ' .pricing-list p' ]['color']             = Startup_Sanitize::color( $price[ 'pricing_table_text_color_' . $unique_id ] );
				$css['global'][ $post_class . ' .pricing-item.item-' . $i . ' .pricing-amount' ]['color']             = Startup_Sanitize::color( $price[ 'pricing_amount_color_' . $unique_id ] );
				$css['global'][ $post_class . ' .pricing-item.item-' . $i . ' .pricing-list p:before' ]['background'] = Startup_Sanitize::color( $price[ 'pricing_amount_color_' . $unique_id ] );
			}
		}

		/**
		 * Clients Section.
		 */
		startup_map_css_selectors( $css['global'], Startup_Sanitize::typography( startup_get_settings( 'clients_heading_font_' . $unique_id ) ) );
		startup_map_css_selectors( $css['global'], Startup_Sanitize::typography( startup_get_settings( 'clients_subheading_font_' . $unique_id ) ) );

		/**
		 * Testimonials
		 */
		startup_map_css_selectors( $css['global'], Startup_Sanitize::typography( startup_get_settings( 'testimonials_heading_font_' . $unique_id ) ) );
		startup_map_css_selectors( $css['global'], Startup_Sanitize::typography( startup_get_settings( 'testimonials_subheading_font_' . $unique_id ) ) );
		startup_map_css_selectors( $css['global'], Startup_Sanitize::typography( startup_get_settings( 'testimonials_name_font_' . $unique_id ) ) );
		startup_map_css_selectors( $css['global'], Startup_Sanitize::typography( startup_get_settings( 'testimonials_profession_font_' . $unique_id ) ) );
		startup_map_css_selectors( $css['global'], Startup_Sanitize::typography( startup_get_settings( 'testimonials_desc_font_' . $unique_id ) ) );
		$css['global'][ $post_class . ' .testimonial-item img' ]['border-radius'] = Startup_Sanitize::size( startup_get_settings( 'testimonials_border_radius_' . $unique_id ) . 'px' );

		/**
		 * Counters
		 */
		startup_map_css_selectors( $css['global'], Startup_Sanitize::typography( startup_get_settings( 'counters_heading_font_' . $unique_id ) ) );
		startup_map_css_selectors( $css['global'], Startup_Sanitize::typography( startup_get_settings( 'counters_subheading_font_' . $unique_id ) ) );
		startup_map_css_selectors( $css['global'], Startup_Sanitize::typography( startup_get_settings( 'counters_title_font_' . $unique_id ) ) );
		startup_map_css_selectors( $css['global'], Startup_Sanitize::typography( startup_get_settings( 'counters_number_font_' . $unique_id ) ) );

		/**
		 * Blog Section.
		 */
		startup_merge_value( $css['global'][ $post_class . ' .layout-grid .post-info' ], Startup_Sanitize::padding( startup_get_settings( 'mts_meta_info_padding_front_' . $unique_id ) ) );
		startup_merge_value( $css['global'][ $post_class . ' .layout-grid .post-info' ], Startup_Sanitize::margin( startup_get_settings( 'mts_meta_info_margin_front_' . $unique_id ) ) );

		startup_map_css_selectors( $css['global'], Startup_Sanitize::typography( startup_get_settings( 'blog_heading_font_' . $unique_id ) ) );
		startup_map_css_selectors( $css['global'], Startup_Sanitize::typography( startup_get_settings( 'blog_subheading_font_' . $unique_id ) ) );
		startup_map_css_selectors( $css['global'], Startup_Sanitize::typography( startup_get_settings( 'blog_title_font_' . $unique_id ) ) );
		startup_map_css_selectors( $css['global'], Startup_Sanitize::typography( startup_get_settings( 'blog_title_font_' . $unique_id ) ) );
		startup_map_css_selectors( $css['global'], Startup_Sanitize::typography( startup_get_settings( 'meta_info_front_font_' . $unique_id ) ) );

	endforeach;
}

/**
 * Layout CSS
 *
 * @param array $css Array of dynamic CSS.
 */
function startup_post_layouts( &$css ) {

	// Post Layouts.
	$features = startup_get_settings( 'mts_featured_categories' );
	foreach ( $features as $feature ) :

		if ( ! isset( $feature['unique_id'] ) ) {
			continue;
		}

		$category     = $feature['mts_featured_category'];
		$posts_layout = isset( $feature['blog_layout'] ) ? $feature['blog_layout'] : 'layout-default';
		$unique_id    = $feature['unique_id'];

		if ( 'layout-default' === $posts_layout ) :
			$posts_layout = 'default';
		endif;

		// Container Class.
		if ( ! in_array( $posts_layout, array( 'default' ) ) ) :
			$container_class = array(
				'.layout-' . $unique_id,
			);

			$css['global'][ startup_implode( $container_class ) ] = array(
				'width'    => '100%',
				'float'    => 'none',
				'overflow' => 'visible',
				'position' => 'relative',
			);
		endif;
		if ( ! in_array( $posts_layout, array( 'default' ) ) ) :
			$all_class                                      = array(
				'.layout-' . $unique_id . ' .latestPost .title',
			);
			$css['global'][ startup_implode( $all_class ) ] = array(
				'line-height' => '1',
				'font-size'   => 'inherit',
			);
		endif;

		// Section title align.
		$post_title_align = startup_get_settings( 'mts_post_title_alignment_' . $unique_id );

		// Post area.
		$cat_class = 'cat-latest';
		if ( 'latest' !== $category ) {
			$category  = get_term_by( 'slug', $category, 'category' );
			$cat_class = sanitize_key( $category->name );
		}

		$title_class = '.title-container.title-id-' . $unique_id . ' h3';

		$css['global'][ $title_class ] = Startup_Sanitize::background( startup_get_settings( 'mts_featured_category_title_background_' . $unique_id ) );
		startup_merge_value( $css['global'][ $title_class ], Startup_Sanitize::margin( startup_get_settings( 'mts_featured_category_title_margin_' . $unique_id ) ) );
		startup_merge_value( $css['global'][ $title_class ], Startup_Sanitize::padding( startup_get_settings( 'mts_featured_category_title_padding_' . $unique_id ) ) );
		// Section title border.
		$post_title_border = Startup_Sanitize::border( startup_get_settings( 'post_title_border_' . $unique_id ) );
		$css['global'][ $title_class ][ $post_title_border['direction'] ] = $post_title_border['value'];

		// Title alignment.
		$align_class = '.title-container.title-id-' . $unique_id;
		if ( 'center' === $post_title_align ) :
			$css['global'][ $align_class ]['text-align'] = 'center';
		elseif ( 'right' === $post_title_align ) :
			$css['global'][ $align_class ]['text-align']              = 'right';
			$css['global'][ $align_class . ' + .view-more' ]['left']  = '0';
			$css['global'][ $align_class . ' + .view-more' ]['right'] = 'auto';
		endif;

		startup_map_css_selectors( $css['global'], Startup_Sanitize::typography( startup_get_settings( 'mts_featured_category_title_font_' . $unique_id ) ) );

		if ( 'layout-grid' !== $posts_layout ) {
			$post_class = '.layout-' . $unique_id . '.default-container';
		} else {
			$post_class = '.layout-' . $unique_id;
		}

		// Post border.
		$post_border = Startup_Sanitize::border( startup_get_settings( 'post_border_' . $unique_id ) );
		$css['global'][ $post_class ][ $post_border['direction'] ] = $post_border['value'];

		startup_merge_value( $css['global'][ $post_class ], Startup_Sanitize::margin( startup_get_settings( 'post_margin_' . $unique_id ) ) );
		startup_merge_value( $css['global'][ $post_class ], Startup_Sanitize::padding( startup_get_settings( 'post_padding_' . $unique_id ) ) );
		startup_merge_value( $css['global'][ $post_class ], Startup_Sanitize::background( startup_get_settings( 'mts_featured_category_background_' . $unique_id ) ) );

		/**
		 * Meta info
		 */

		startup_map_css_selectors( $css['global'], Startup_Sanitize::typography( startup_get_settings( 'meta_info_font_' . $unique_id ) ) );

		startup_merge_value( $css['global'][ '.layout-' . $unique_id . ' .latestPost .post-info' ], Startup_Sanitize::margin( startup_get_settings( 'mts_meta_info_margin_' . $unique_id ) ) );

		startup_merge_value( $css['global'][ '.layout-' . $unique_id . ' .latestPost .post-info > span' ], Startup_Sanitize::padding( startup_get_settings( 'mts_meta_info_padding_' . $unique_id ) ) );

		$css['global'][ '.layout-' . $unique_id . ' .post-info > span' ]['background-color'] = Startup_Sanitize::color( startup_get_settings( 'home_meta_info_bg_' . $unique_id ) );

		startup_map_css_selectors( $css['global'], Startup_Sanitize::typography( startup_get_settings( 'post_title_font_' . $unique_id ) ) );

		//if ( 'layout-grid' !== $posts_layout ) {
		startup_map_css_selectors( $css['global'], Startup_Sanitize::typography( startup_get_settings( 'post_excerpt_font_' . $unique_id ) ) );

		// Border.
		$meta_info_border = Startup_Sanitize::border( startup_get_settings( 'meta_info_border_' . $unique_id ) );
		$css['global'][ '.layout-' . $unique_id . ' .layout-default .latestPost .post-info' ][ $meta_info_border['direction'] ] = $meta_info_border['value'];

		// Read More.
		startup_merge_value( $css['global'][ $post_class . ' .readMore .button' ], Startup_Sanitize::background( startup_get_settings( 'readmore_bg_' . $unique_id ) ) );
		$css['global'][ $post_class . ' .readMore .button' ]['color'] = Startup_Sanitize::color( startup_get_settings( 'readmore_color_' . $unique_id ) );
		$css['global'][ $post_class . ' .readMore svg path' ]['fill'] = Startup_Sanitize::color( startup_get_settings( 'readmore_color_' . $unique_id ) );
		startup_merge_value( $css['global'][ $post_class . ' .readMore .button' ], Startup_Sanitize::padding( startup_get_settings( 'readmore_padding_' . $unique_id ) ) );
		startup_merge_value( $css['global'][ $post_class . ' .readMore' ], Startup_Sanitize::margin( startup_get_settings( 'readmore_margin_' . $unique_id ) ) );

	endforeach;
}

/**
 * Pagination
 *
 * @param array $css Array of dynamic CSS.
 */
function startup_post_pagination( &$css ) {

	// Pagination Active class.
	$pagination_class_active = array(
		'.pace .pace-progress',
		'.page-numbers.current',
		'.pagination a:hover',
		'#mobile-menu-wrapper ul li a:hover',
		'#load-posts a:hover',
	);
	$pagination_class        = array(
		'.pagination a',
		'#load-posts a',
		'.single .pagination > .current > .currenttext',
		'.pagination .page-numbers.dots',
	);
	if ( '2' !== startup_get_settings( 'mts_pagenavigation_type' ) ) {
		$css['global'][ startup_implode( $pagination_class ) ]['background-color']        = Startup_Sanitize::color( startup_get_settings( 'mts_pagenavigation_bgcolor' ) );
		$css['global'][ startup_implode( $pagination_class_active ) ]['background-color'] = Startup_Sanitize::color( startup_get_settings( 'mts_pagenavigation_hover_bgcolor' ) );
		$css['global'][ startup_implode( $pagination_class ) ]['color']                   = Startup_Sanitize::color( startup_get_settings( 'mts_pagenavigation_color' ) );
		$css['global'][ startup_implode( $pagination_class_active ) ]['color']            = Startup_Sanitize::color( startup_get_settings( 'mts_pagenavigation_hover_color' ) );
		$css['global']['.pagination .page-numbers i']['color']                            = Startup_Sanitize::color( startup_get_settings( 'mts_pagenavigation_hover_bgcolor' ) );
		$css['global']['.pagination-previous-next i']['color']                            = Startup_Sanitize::color( startup_get_settings( 'mts_pagenavigation_hover_bgcolor' ) );
		$css['global']['.pagination .page-numbers:hover i']['color']                      = Startup_Sanitize::color( startup_get_settings( 'mts_pagenavigation_hover_color' ) );
		$css['global']['.pagination-previous-next a:hover i']['color']                    = Startup_Sanitize::color( startup_get_settings( 'mts_pagenavigation_hover_color' ) );
		startup_merge_value( $css['global'][ startup_implode( array_merge( $pagination_class_active, $pagination_class ) ) ], Startup_Sanitize::margin( startup_get_settings( 'mts_pagenavigation_margin' ) ) );
		startup_merge_value( $css['global'][ startup_implode( array_merge( $pagination_class_active, $pagination_class ) ) ], Startup_Sanitize::padding( startup_get_settings( 'mts_pagenavigation_padding' ) ) );
		$css['global'][ startup_implode( startup_implode( array_merge( $pagination_class_active, $pagination_class ) ) ) ]['border-radius'] = Startup_Sanitize::size( startup_get_settings( 'mts_pagenavigation_border_radius' ) . 'px' );
	} else {
		$css['global'][ startup_implode( $pagination_class ) ]['background-color']        = Startup_Sanitize::color( startup_get_settings( 'load_more_bgcolor' ) );
		$css['global'][ startup_implode( $pagination_class_active ) ]['background-color'] = Startup_Sanitize::color( startup_get_settings( 'load_more_hover_bgcolor' ) );
		$css['global'][ startup_implode( $pagination_class ) ]['color']                   = Startup_Sanitize::color( startup_get_settings( 'load_more_color' ) );
		$css['global'][ startup_implode( $pagination_class_active ) ]['color']            = Startup_Sanitize::color( startup_get_settings( 'load_more_hover_color' ) );
		startup_merge_value( $css['global']['#load-posts a'], Startup_Sanitize::padding( startup_get_settings( 'load_more_padding' ) ) );
		$css['global'][ startup_implode( startup_implode( array_merge( $pagination_class_active, $pagination_class ) ) ) ]['border-radius'] = Startup_Sanitize::size( startup_get_settings( 'mts_loadmore_border_radius' ) . 'px' );
	}

	// Pagination border.
	$pagination_border = Startup_Sanitize::border( startup_get_settings( 'pagenavigation_border' ) );
	$css['global'][ startup_implode( $pagination_class ) ][ $pagination_border ['direction'] ] = $pagination_border ['value'];

	// Pagination Alignment.
	$pagenavigation_align = startup_get_settings( 'pagenavigation_alignment' );
	if ( 'left' === $pagenavigation_align ) :
		$css['global']['.pagination']['text-align'] = 'left';
	elseif ( 'right' === $pagenavigation_align ) :
		$css['global']['.pagination']['text-align'] = 'right';
	endif;

	// Load more Alignment.
	$load_more_align = startup_get_settings( 'load_more_alignment' );
	if ( 'left' === $load_more_align ) :
		$css['global']['#load-posts']['text-align'] = 'left';
	elseif ( 'right' === $load_more_align ) :
		$css['global']['#load-posts']['text-align'] = 'right';
	elseif ( 'full' === $load_more_align ) :
		$css['global']['#load-posts a']['width'] = '100%';
	endif;
}

/**
 * Single
 *
 * @param array $css Array of dynamic CSS.
 */
function startup_single( &$css ) {

	// Single, Page, Archive, Search, Category and 404 Page Background.
	$page_classes = array(
		'.single .article',
		'.page .article',
		'.search .article',
		'.archive .article',
		'.error404 .article',
	);

	$css['global'][ startup_implode( $page_classes ) ] = Startup_Sanitize::background( startup_get_settings( 'single_background' ) );

	// Margin, Padding, Border and Box Shadow.
	startup_merge_value( $css['global'][ startup_implode( $page_classes ) ], Startup_Sanitize::margin( startup_get_settings( 'mts_single_styling_margin' ) ) );
	startup_merge_value( $css['global'][ startup_implode( $page_classes ) ], Startup_Sanitize::padding( startup_get_settings( 'mts_single_styling_padding' ) ) );

	// Single border.
	$single_border = Startup_Sanitize::border( startup_get_settings( 'single_styling_border' ) );
	$css['global']['.article'][ $single_border ['direction'] ] = $single_border ['value'];

	startup_map_css_selectors( $css['global'], Startup_Sanitize::typography( startup_get_settings( 'mts_single_meta_info_font' ) ) );
	// Tags.
	$css['global']['.tags a, .tagcloud a, .widget .wpt_widget_content #tags-tab-content ul li a']['background-color'] = Startup_Sanitize::color( startup_get_settings( 'tags_bgcolor' ) );

	// Related Posts.
	$css['global']['.related-posts'] = Startup_Sanitize::background( startup_get_settings( 'related_posts_background' ) );
	startup_map_css_selectors( $css['global'], Startup_Sanitize::typography( startup_get_settings( 'related_posts_font' ) ) );
	startup_map_css_selectors( $css['global'], Startup_Sanitize::typography( startup_get_settings( 'related_posts_meta_font' ) ) );
	startup_map_css_selectors( $css['global'], Startup_Sanitize::typography( startup_get_settings( 'related_posts_excerpt' ) ) );
	startup_merge_value( $css['global']['.related-posts'], Startup_Sanitize::margin( startup_get_settings( 'related_posts_margin' ) ) );
	startup_merge_value( $css['global']['.related-posts'], Startup_Sanitize::padding( startup_get_settings( 'related_posts_padding' ) ) );

	$related_posts_border = Startup_Sanitize::border( startup_get_settings( 'related_posts_border' ) );
	$css['global']['.related-posts'][ $related_posts_border ['direction'] ] = $related_posts_border ['value'];

	// Related Posts articles.
	$css['global']['.related-posts article'] = Startup_Sanitize::background( startup_get_settings( 'related_article_background' ) );
	startup_merge_value( $css['global']['.related-posts article'], Startup_Sanitize::padding( startup_get_settings( 'related_article_padding' ) ) );
	startup_merge_value( $css['global']['.related-posts article header'], Startup_Sanitize::padding( startup_get_settings( 'related_article_text_padding' ) ) );
	// Subscribe Box.
	$css['global']['.single-subscribe .widget #wp-subscribe'] = Startup_Sanitize::background( startup_get_settings( 'single_subscribe_background' ) );
	startup_merge_value( $css['global']['.single-subscribe .widget #wp-subscribe'], Startup_Sanitize::margin( startup_get_settings( 'single_subscribe_margin' ) ) );
	startup_merge_value( $css['global']['.single-subscribe .widget #wp-subscribe'], Startup_Sanitize::padding( startup_get_settings( 'single_subscribe_padding' ) ) );
	$css['global']['.single-subscribe .widget #wp-subscribe']['border-radius'] = Startup_Sanitize::size( startup_get_settings( 'single_subscribe_border_radius' ) . 'px' );

	// Subscribe Box Input fields.
	$subscribe_input_class = array(
		'.single-subscribe #wp-subscribe input.email-field',
		'.single-subscribe #wp-subscribe input.name-field',
	);
	$css['global'][ startup_implode( $subscribe_input_class ) ]['background-color'] = Startup_Sanitize::color( startup_get_settings( 'single_subscribe_input_background' ) );

	$css['global'][ startup_implode( $subscribe_input_class ) ]['height'] = Startup_Sanitize::size( startup_get_settings( 'single_subscribe_input_height' ) . 'px' );

	$css['global']['.single-subscribe .widget #wp-subscribe input.submit']['height'] = Startup_Sanitize::size( startup_get_settings( 'single_subscribe_input_height' ) . 'px' );

	// Subscribe Box Input border.
	$subscribe_box_input_border = Startup_Sanitize::border( startup_get_settings( 'single_subscribe_input_border' ) );
	$css['global'][ startup_implode( $subscribe_input_class ) ][ $subscribe_box_input_border ['direction'] ] = $subscribe_box_input_border ['value'];

	// Subscribe Box Submit button.
	startup_merge_value( $css['global']['.single-subscribe .widget #wp-subscribe input.submit'], Startup_Sanitize::background( startup_get_settings( 'single_subscribe_submit_backgroud' ) ) );

	// Subscribe Box Submit border.
	$subscribe_box_submit_border = Startup_Sanitize::border( startup_get_settings( 'single_subscribe_submit_border' ) );
	$css['global']['.single-subscribe .widget #wp-subscribe input.submit'][ $subscribe_box_submit_border ['direction'] ] = $subscribe_box_submit_border ['value'];

	startup_merge_value( $css['global']['.single-subscribe .widget #wp-subscribe input.submit'], Startup_Sanitize::padding( startup_get_settings( 'single_subscribe_submit_padding' ) ) );

	// Author Box.
	$css['global']['.postauthor'] = Startup_Sanitize::background( startup_get_settings( 'single_authorbox_background' ) );
	startup_merge_value( $css['global']['.postauthor'], Startup_Sanitize::margin( startup_get_settings( 'single_authorbox_margin' ) ) );
	startup_merge_value( $css['global']['.postauthor'], Startup_Sanitize::padding( startup_get_settings( 'single_authorbox_padding' ) ) );
	$css['global']['.postauthor']['border-radius'] = Startup_Sanitize::size( startup_get_settings( 'single_authorbox_border_radius' ) . 'px' );
	$single_authorbox_border                       = Startup_Sanitize::border( startup_get_settings( 'single_authorbox_border' ) );
	$css['global']['.postauthor'][ $single_authorbox_border ['direction'] ] = $single_authorbox_border ['value'];
	// Author image.
	startup_merge_value( $css['global']['.postauthor img'], Startup_Sanitize::margin( startup_get_settings( 'single_author_image_margin' ) ) );
	$css['global']['.postauthor img']['border-radius'] = Startup_Sanitize::size( startup_get_settings( 'single_author_image_border_radius' ) . 'px' );
	// Author Social
	startup_merge_value( $css['global']['.author-social a'], Startup_Sanitize::margin( startup_get_settings( 'author_social_margin' ) ) );
	//startup_merge_value( $css['global']['.author-social a'], Startup_Sanitize::padding( startup_get_settings( 'author_social_padding' ) ) );
	$css['global']['.author-social a']['min-width']     = Startup_Sanitize::size( startup_get_settings( 'author_social_width' ) . 'px' );
	$css['global']['.author-social a']['height']        = Startup_Sanitize::size( startup_get_settings( 'author_social_height' ) . 'px' );
	$css['global']['.author-social a']['line-height']   = Startup_Sanitize::size( startup_get_settings( 'author_social_height' ) . 'px' );
	$css['global']['.author-social a']['border-radius'] = Startup_Sanitize::size( startup_get_settings( 'author_social_border_radius' ) . 'px' );

	$single_author_image_margin = Startup_Sanitize::margin( startup_get_settings( 'single_author_image_margin' ) );
	// Top, Right, Bottom, Left Position.
	$css['global']['.author-social']['padding-left'] = (int) $single_author_image_margin['margin-right'] + '100' . 'px';

	// Single Page titles Styling.
	$titles_align = startup_get_settings( 'single_title_alignment' );

	$titles_align_class = array(
		'.comment-title',
		'#respond',
		'.related-posts-title',
	);
	$titles_class       = array(
		'#respond h3',
		'#respond h4',
		'.total-comments',
		'.related-posts h4',
	);

	$css['global'][ startup_implode( $titles_class ) ] = Startup_Sanitize::background( startup_get_settings( 'single_title_background' ) );
	startup_merge_value( $css['global'][ startup_implode( $titles_class ) ], Startup_Sanitize::padding( startup_get_settings( 'single_title_padding' ) ) );
	// Single title border.
	$single_titles_border = Startup_Sanitize::border( startup_get_settings( 'single_title_border' ) );
	$css['global'][ startup_implode( $titles_class ) ][ $single_titles_border ['direction'] ] = $single_titles_border ['value'];

	if ( 'left' === $titles_align ) :
		$css['global'][ startup_implode( $titles_class ) ]['display'] = 'inline-block';
	elseif ( 'center' === $titles_align ) :
		$css['global'][ startup_implode( $titles_align_class ) ]['text-align'] = 'center';
		$css['global'][ startup_implode( $titles_class ) ]['display']          = 'inline-block';
	elseif ( 'right' === $titles_align ) :
		$css['global'][ startup_implode( $titles_align_class ) ]['text-align'] = 'right';
		$css['global'][ startup_implode( $titles_class ) ]['display']          = 'inline-block';
	endif;

	// Pages Titles section.
	startup_merge_value( $css['global']['.pages-title-section'], Startup_Sanitize::margin( startup_get_settings( 'pages_title_margin' ) ) );
	startup_merge_value( $css['global']['.pages-title-section'], Startup_Sanitize::padding( startup_get_settings( 'pages_title_padding' ) ) );
}

/**
 * Footer
 *
 * @param array $css Array of dynamic CSS.
 */
function startup_footer( &$css ) {

	// Footer.
	startup_merge_value( $css['global']['#site-footer'], Startup_Sanitize::margin( startup_get_settings( 'mts_top_footer_margin' ) ) );
	startup_merge_value( $css['global']['#site-footer'], Startup_Sanitize::padding( startup_get_settings( 'mts_top_footer_padding' ) ) );

	// Footer widgets.
	if ( startup_get_settings( 'mts_top_footer' ) && 1 === startup_get_settings( 'mts_top_footer_num' ) ) :
		$css['global']['.footer-widgets']['display']                = 'flex';
		$css['global']['.footer-widgets']['justify-content']        = 'center';
		$css['global']['.footer-widgets .f-widget']['width']        = '38.7387388%';
		$css['global']['.footer-widgets .f-widget']['text-align']   = 'center';
		$css['global']['.footer-widgets .f-widget']['margin-right'] = '0px';
	endif;

	// Copyrights.
	$css['global']['.copyrights'] = Startup_Sanitize::background( startup_get_settings( 'mts_copyrights_background' ) );
	startup_merge_value( $css['global']['.copyrights'], Startup_Sanitize::margin( startup_get_settings( 'copyrights_margin' ) ) );
	startup_merge_value( $css['global']['.copyrights'], Startup_Sanitize::padding( startup_get_settings( 'copyrights_padding' ) ) );
	// copyrights border.
	$copyrights_border = Startup_Sanitize::border( startup_get_settings( 'copyrights_border' ) );
	$css['global']['.copyrights .container'][ $copyrights_border ['direction'] ] = $copyrights_border ['value'];

	// footer Nav alignment.
	$footer_nav_align = startup_get_settings( 'footer_nav_alignment' );
	if ( 'left' === $footer_nav_align ) :
		$css['global']['.footer-nav-section']['text-align'] = 'left';
	elseif ( 'center' === $footer_nav_align ) :
		$css['global']['.footer-nav-section']['text-align'] = 'center';
	elseif ( 'right' === $footer_nav_align ) :
		$css['global']['.footer-nav-section']['text-align'] = 'right';
	endif;

	// footer Nav menu item.
	startup_merge_value( $css['global']['.footer-navigation li a'], Startup_Sanitize::margin( startup_get_settings( 'footer_menu_item_margin' ) ) );

	// footer Nav separator.
	startup_merge_value( $css['global']['.footer-nav-container .footer-separator'], Startup_Sanitize::margin( startup_get_settings( 'footer_nav_separator_margin' ) ) );
	$css['global']['.footer-nav-container .footer-separator']['color'] = Startup_Sanitize::color( startup_get_settings( 'footer_nav_separator_color' ) );

	// Footer Logo Social icons.
	if ( 1 === startup_get_settings( 'footer_logo_social_icons' ) && ! empty( startup_get_settings( 'footer_logo_social' ) ) && is_array( startup_get_settings( 'footer_logo_social' ) ) ) :
		$footer_nav_icons = startup_get_settings( 'footer_logo_social' );
		foreach ( $footer_nav_icons as $footer_nav_icon ) :
			$footer_icons[]               = $footer_nav_icon['footer_logo_social_icon'];
			$footer_nav_icon_border_size  = $footer_nav_icon['footer_logo_social_border_size'];
			$footer_nav_icon_border_style = $footer_nav_icon['footer_logo_social_border_style'];
			$footer_nav_icon_border_color = $footer_nav_icon['footer_logo_social_border_color'];
			$footer_nav_icon_border       = $footer_nav_icon_border_size . 'px ' . $footer_nav_icon_border_style . ' ' . $footer_nav_icon_border_color;
			$css['global'][ '.footer-logo-social-icons a.footer-logo-' . $footer_nav_icon['footer_logo_social_icon'] ]['background-color']            = Startup_Sanitize::color( $footer_nav_icon['footer_logo_social_bgcolor'] );
			$css['global'][ '.footer-logo-social-icons a.footer-logo-' . $footer_nav_icon['footer_logo_social_icon'] . ':hover' ]['background-color'] = Startup_Sanitize::color( $footer_nav_icon['footer_logo_social_hover_bgcolor'] );
			$css['global'][ '.footer-logo-social-icons a.footer-logo-' . $footer_nav_icon['footer_logo_social_icon'] ]['color']                       = Startup_Sanitize::color( $footer_nav_icon['footer_logo_social_color'] );
			$css['global'][ '.footer-logo-social-icons a.footer-logo-' . $footer_nav_icon['footer_logo_social_icon'] . ':hover' ]['color']            = Startup_Sanitize::color( $footer_nav_icon['footer_logo_social_hover_color'] );
			startup_merge_value( $css['global'][ '.footer-logo-social-icons a.footer-logo-' . $footer_nav_icon['footer_logo_social_icon'] ], Startup_Sanitize::margin( $footer_nav_icon['footer_logo_social_margin'] ) );
			startup_merge_value( $css['global'][ '.footer-logo-social-icons a.footer-logo-' . $footer_nav_icon['footer_logo_social_icon'] ], Startup_Sanitize::padding( $footer_nav_icon['footer_logo_social_padding'] ) );
			$css['global'][ '.footer-logo-social-icons a.footer-logo-' . $footer_nav_icon['footer_logo_social_icon'] ]['border-radius'] = Startup_Sanitize::size( $footer_nav_icon['footer_logo_social_border_radius'] . 'px' );
			$css['global'][ '.footer-logo-social-icons a.footer-logo-' . $footer_nav_icon['footer_logo_social_icon'] ]['border']        = $footer_nav_icon_border;
		endforeach;
	endif;

	// Footer Nav Social icons font size.
	if ( ! empty( $footer_icons ) && is_array( $footer_icons ) ) :
		foreach ( $footer_icons as $footer_icon ) :
			$css['global'][ '.footer-logo-social-icons a.footer-logo-' . $footer_icon ]['font-size'] = Startup_Sanitize::size( startup_get_settings( 'footer_logo_social_font_size' ) . 'px' );
		endforeach;
	endif;

	// Footer Brands Sections.
	$brands_border = Startup_Sanitize::border( startup_get_settings( 'brands_border' ) );
	$css['global']['.brands-container'][ $brands_border ['direction'] ] = $brands_border ['value'];

	// footer brands alignment.
	$footer_brands_align = startup_get_settings( 'footer_brands_alignment' );
	if ( 'center' === $footer_brands_align ) :
		$css['global']['.brands-container']['justify-content'] = 'center';
	elseif ( 'right' === $footer_brands_align ) :
		$css['global']['.brands-container']['justify-content'] = 'flex-end';
	endif;

	// brand container.
	startup_merge_value( $css['global']['.brands-container'], Startup_Sanitize::margin( startup_get_settings( 'brands_margin' ) ) );
	startup_merge_value( $css['global']['.brands-container'], Startup_Sanitize::padding( startup_get_settings( 'brands_padding' ) ) );

}

/**
 * Misc
 *
 * @param array $css Array of dynamic CSS.
 */
function startup_misc_css( &$css ) {

	// Show Logo.
	$show_logo = startup_get_settings( 'mts_header_section2' );

	if ( 0 === $show_logo ) {
		$css['global']['.logo-wrap']['display'] = 'none';
	}

	// Back to top.
	// Border.
	$top_button_border = Startup_Sanitize::border( startup_get_settings( 'top_button_border' ) );
	$css['global']['#move-to-top'][ $top_button_border ['direction'] ] = $top_button_border ['value'];
	// Font-size, Padding and Position.
	$css['global']['#move-to-top .fa']['font-size'] = Startup_Sanitize::size( startup_get_settings( 'top_button_font_size' ) . 'px' );
	//Top button position
	$top_button_position = startup_get_settings( 'top_button_position' );
	foreach ( $top_button_position as $key => $position ) {
		$css['global']['#move-to-top'][ $key ] = $position;
	}
	// Border-radius.
	$css['global']['#move-to-top']['border-radius'] = Startup_Sanitize::size( startup_get_settings( 'top_button_border_radius' ) . 'px' );
	// Height Width of back to top
	$css['global']['#move-to-top']['min-width']     = Startup_Sanitize::size( startup_get_settings( 'top_button_width' ) . 'px' );
	$css['global']['#move-to-top']['height']        = Startup_Sanitize::size( startup_get_settings( 'top_button_height' ) . 'px' );
	$css['global']['#move-to-top i']['line-height'] = Startup_Sanitize::size( startup_get_settings( 'top_button_height' ) . 'px' );
	// Colors.
	$css['global']['#move-to-top']['color']            = Startup_Sanitize::color( startup_get_settings( 'top_button_color' ) );
	$css['global']['#move-to-top:hover']['color']      = Startup_Sanitize::color( startup_get_settings( 'top_button_color_hover' ) );
	$css['global']['#move-to-top']['background']       = Startup_Sanitize::color( startup_get_settings( 'top_button_background' ) );
	$css['global']['#move-to-top:hover']['background'] = Startup_Sanitize::color( startup_get_settings( 'top_button_background_hover' ) );
}
